@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.558";
+our $VERSION = "0.559";
 
 1;
 
@@ -1685,6 +1685,44 @@ Exceptions:
 
 Exceptions thrown by L<Fn#rand|SPVM::Fn/"rand"> method could be thrown.
 
+=head2 set_tcp_keepidle
+
+C<static method set_tcp_keepidle : void ($socket_fd : int, $keepidle_sec : int);>
+
+Sets the TCP keep-alive idle time (C<TCP_KEEPIDLE> or C<TCP_KEEPALIVE> on macOS) in seconds.
+
+Notes:
+
+This method calls L<Sys#setsockopt|SPVM::Sys/"setsockopt"> to set the socket option at the C<IPPROTO_TCP> level.
+
+On macOS, this method uses the C<TCP_KEEPALIVE> constant instead of C<TCP_KEEPIDLE>.
+
+=head2 get_tcp_keepidle
+
+C<static method get_tcp_keepidle : int ($socket_fd : int);>
+
+Gets the current TCP keep-alive idle time (C<TCP_KEEPIDLE> or C<TCP_KEEPALIVE> on macOS) in seconds.
+
+Notes:
+
+This method calls L<Sys#getsockopt|SPVM::Sys/"getsockopt"> at the C<IPPROTO_TCP> level and returns the result as an integer.
+
+On macOS, this method uses the C<TCP_KEEPALIVE> constant instead of C<TCP_KEEPIDLE>.
+
+=head2 set_tcp_keepidle_portable
+
+C<static method set_tcp_keepidle_portable : void ($socket_fd : int, $keepidle_sec : int);>
+
+Sets the TCP keep-alive idle time in seconds in a portable way.
+
+Notes:
+
+On Windows, this method calls L<Sys::Socket#win_set_tcp_keepalive|SPVM::Sys::Socket/"win_set_tcp_keepalive"> via C<WSAIoctl> with the C<SIO_KEEPALIVE_VALS> control code. It also enables keep-alive (C<onoff = 1>) and sets the retry interval to 1 second (1000ms).
+
+On other systems, this method calls L<set_tcp_keepidle|/"set_tcp_keepidle">.
+
+See also L<set_tcp_keepidle|/"set_tcp_keepidle"> and L<Sys::Socket#win_set_tcp_keepalive|SPVM::Sys::Socket/"win_set_tcp_keepalive">.
+
 =head1 Modules
 
 =over 2
