@@ -20,7 +20,7 @@ Sys::Ioctl::Constant class in L<SPVM> has methods to get constant values for the
 
 C<static method FIONBIO : int ();>
 
-Gets the value of C<FIONBIO>. If the value is not defined in this system, an exception is thrown with C<eval_error_id> set to the basic type ID of L<Error::NotSupported|SPVM::Error::NotSupported> class.
+Gets the value of C<FIONBIO>. If the value is not defined in this system, an L<Error::NotSupported|SPVM::Error::NotSupported> exception is thrown.
 
 =head1 See Also
 
